@@ -62,7 +62,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def status(self, read_data_flag: bool) -> DwfState:
         """Get the |DigitalIn| instrument state.
 
-        Executing this method initiates a status request to the |DigitalIn| instrument and receives its response.
+        This method performs a status request to the |DigitalIn| instrument and receives its response.
 
         The following methods can be used to retrieve |DigitalIn| instrument status information
         as a result of this call, regardless of the value of the *read_data_flag* parameter:
@@ -166,10 +166,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samplesLeft
 
     def statusSamplesValid(self) -> int:
-        """Retrieve the number of valid/acquired data samples.
+        """Retrieve the number of valid data samples.
 
         Returns:
-            int: The number of valid samples.
+            int: The number of valid samples in the buffer.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -233,7 +233,6 @@ class DigitalIn(AbstractDwfDeviceSubApi):
 
     def statusData(self, count_bytes: int) -> np.ndarray:
         """Retrieve the acquired data samples from the |DigitalIn| instrument.
-        It copies the data samples to the provided buffer.
 
         Todo:
             Figure out the data format.
@@ -311,7 +310,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return hzFreq
 
     def clockSourceInfo(self) -> List[DwfDigitalInClockSource]:
-        """Get the valid clock sources for the |DigitalIn| instrument.
+        """Get a list of valid clock sources for the |DigitalIn| instrument.
 
         Returns:
             List[DwfDigitalInClockSource]: A list of valid clock sources.
@@ -389,6 +388,9 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def dividerGet(self) -> int:
         """Get the current |DigitalIn| instrument divider value.
 
+        If the clock source is internal, the |DigitalIn| sample frequency will be equal
+        to :py:meth:`internalClockInfo` divided by :py:meth:`dividerGet`.
+
         Returns:
             int: The currently configured divider value.
 
@@ -409,10 +411,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
-        """Get the valid |DigitalIn| acquisition modes.
+        """Get a list of valid |DigitalIn| instrument acquisition modes.
 
         Returns:
-            List[DwfAcquisitionMode]: A list of valid acquisition modes.
+            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |DigitalIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -427,10 +429,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return acquisition_mode_list
 
     def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
-        """Set the |DigitalIn| acquisition mode.
+        """Select the |DigitalIn| acquisition mode.
 
         Parameters:
-            acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
+            acquisition_mode (DwfAcquisitionMode): The acquisition mode to be selected.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -440,10 +442,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def acquisitionModeGet(self) -> DwfAcquisitionMode:
-        """Get the |DigitalIn| acquisition mode.
+        """Get the currently selected |DigitalIn| acquisition mode.
 
         Returns:
-            DwfAcquisitionMode: The currently active acquisition mode.
+            DwfAcquisitionMode: The currently selected acquisition mode.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -472,7 +474,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return num_bits
 
     def sampleFormatSet(self, num_bits: int) -> None:
-        """Set the |DigitalIn| sample format (number of bits).
+        """Set the |DigitalIn| sample format (i.e., number of bits).
 
         Parameters:
             num_bits (int): The number of bits per sample (8, 16, or 32).
@@ -485,7 +487,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sampleFormatGet(self) -> int:
-        """Get the |DigitalIn| sample format (number of bits).
+        """Get the |DigitalIn| sample format (i.e., number of bits).
 
         Returns:
             int: The currently configured number of bits per sample (8, 16, or 32).
@@ -501,7 +503,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return num_bits
 
     def inputOrderSet(self, dio_first: bool) -> None:
-        """Configure the |DigitalIn| order of values stored in the sampling array.
+        """Select the |DigitalIn| order of values stored in the sampling array.
 
         If *dio_first* is True, DIO 24…39 are placed at the beginning of the array followed by DIN 0…23.
 
@@ -549,7 +551,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def bufferSizeGet(self) -> int:
-        """Get the |DigitalIn| instrument buffer size.
+        """Get the currently configured |DigitalIn| instrument buffer size.
 
         Returns:
             int: The currently configured buffer size.
@@ -731,10 +733,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get |DigitalIn| instrument trigger source.
+        """Get the currently selected instrument trigger source.
 
         Returns:
-            DwfTriggerSource: The currently configured |DigitalIn| trigger source.
+            DwfTriggerSource: The currently selected instrument trigger source.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -747,10 +749,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
-        """Set |DigitalIn| trigger detector slope.
+        """Select the |DigitalIn| instrument trigger slope.
 
         Parameters:
-            trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
+            trigger_slope (DwfTriggerSlope): The trigger slope to be selected.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -760,10 +762,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self) -> DwfTriggerSlope:
-        """Get |DigitalIn| trigger detector slope.
+        """Get the currently selected |DigitalIn| instrument trigger slope.
 
         Returns:
-            DwfTriggerSlope: The currently configured trigger slope.
+            DwfTriggerSlope: The currently selected |DigitalIn| instrument trigger slope.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -948,7 +950,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         """Get the configured |DigitalIn| trigger detector settings.
 
         Returns:
-            Tuple[int, int, int, int]: The currently active *level_low*, *level_high*, *edge_rise*,
+            Tuple[int, int, int, int]: The currently configured *level_low*, *level_high*, *edge_rise*,
             and *edge_fall* settings.
 
         Raises:
