@@ -102,10 +102,10 @@ class DigitalUart(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def txSet(self, channel_index: int) -> None:
-        """Set the channel where the UART's outgoing (TX) signal will be transmitted.
+        """Set the digital channel (pin) where the UART's outgoing (TX) signal will be transmitted.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to transmit data.
+            channel_index (int): The digital channel (pin) on which to transmit data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -115,10 +115,10 @@ class DigitalUart(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def rxSet(self, channel_index: int) -> None:
-        """Set the channel where the UART's incoming (RX) signal is received.
+        """Set the digital channel (pin) where the UART's incoming (RX) signal is received.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to receive data.
+            channel_index (int): The digital channel (pin) on which to receive data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
