@@ -363,19 +363,19 @@ class DwfDevice:
             raise self.dwf.exception()
 
     def paramGet(self, parameter: DwfDeviceParameter) -> int:
-        """Retrieve a device parameter value.
+        """Get a device parameter value.
 
         Device parameters are settings of a specific |DwfDevice|.
         Refer to the |device parameters:link| section for more information.
 
         Parameters:
-            parameter (DwfDeviceParameter): The device parameter to retrieve.
+            parameter (DwfDeviceParameter): The device parameter to get.
 
         Returns:
             int: The integer value of the parameter.
 
         Raises:
-            DwfLibraryError: The specified device parameter cannot be retrieved.
+            DwfLibraryError: The value of the specified device parameter cannot be retrieved.
         """
         c_value = typespec_ctypes.c_int()
         result = self.lib.FDwfDeviceParamGet(self.hdwf, parameter.value, c_value)
