@@ -74,7 +74,7 @@ class DwfLibrary:
             raise PyDwfError("Unable to open DWF library using ctypes.") from exception
 
         if check_library_version:
-            # Note that the 'FDwfGetVersion' function has not been type-annotated yet here.
+            # Note that the 'FDwfGetVersion()' function has not yet been type-annotated here.
             c_version = ctypes.create_string_buffer(32)
             result = lib.FDwfGetVersion(c_version)
             if result != RESULT_SUCCESS:
@@ -101,6 +101,9 @@ class DwfLibrary:
 
         This property is provided for internal |pydwf| use.
 
+        Returns:
+            ctypes.CDLL: The |ctypes| library.
+
         :meta private:
         """
         return self._lib
@@ -169,7 +172,7 @@ class DwfLibrary:
         c_dwferc = typespec_ctypes.DwfErrorCode()
         result = self._lib.FDwfGetLastError(c_dwferc)
         if result != RESULT_SUCCESS:
-            # If the FDwfGetLastError call itself fails, we cannot get a proper error code or message.
+            # If the 'FDwfGetLastError()' call itself fails, we cannot get a proper error code or message.
             raise DwfLibraryError(None, "FDwfGetLastError() failed.")
         dwferc = DwfErrorCode(c_dwferc.value)
         return dwferc
